get_change_color

Function get_change_color 

fn get_change_color(percent_change: f64) -> ColorSpec
Get a color spec for the given change percentage.

Positive changes are red (regression), negative changes are green (improvement). This represents changes for time durations. For throughput changes, the sign should be inverted before passing to this method.