fn get_change_color(percent_change: f64) -> ColorSpecExpand description
Get a color spec for the given change percentage.
Positive changes are red (regression), negative changes are green (improvement). This represents changes for time durations. For throughput changes, the sign should be inverted before passing to this method.